Easy DNA
========

Easy_dna is a Python library implementing useful routines for manipulating DNA
sequences, either as "ATGC" strings or Biopython records. It aims at providing
a simpler interface than Biopython for common operations related to DNA sequence
design and genbank generation.

**Github Page**: `<https://github.com/Edinburgh-Genome-Foundry/easy_dna>`_

**License:** MIT

Copyright 2019, 2020, 2021, 2024 Edinburgh Genome Foundry, University of Edinburgh


More biology software
---------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

Easy DNA is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_ synthetic biology software suite for DNA design, manufacturing and validation.
